@@ -8,10 +8,14 @@ from syrupy.types import SnapshotIndex
 
 
 class SchemaOutputExtension(JSONSnapshotExtension):
+    _file_extension = ""
+
     @classmethod
     def dirname(cls, *, test_location: "PyTestLocation") -> str:
         return str(
-            Path(test_location.filepath).parent.parent.parent.joinpath("dist/provider")
+            Path(test_location.filepath).parent.parent.parent.joinpath(
+                "output/provider"
+            )
         )
 
     @classmethod
